# Change Log

All notable changes to this project will be documented in this file
automatically by Versionist. DO NOT EDIT THIS FILE MANUALLY!
This project adheres to [Semantic Versioning](http://semver.org/).

# v4.11.84
## (2025-07-22)

* patch: Replace balenalib with Docker Official image [Vipul Gupta (@vipulgupta2048)]

# v4.11.83
## (2025-04-14)

* Update actions/setup-node digest to 49933ea [balena-renovate[bot]]

# v4.11.82
## (2025-03-19)

* Update actions/upload-artifact digest to ea165f8 [balena-renovate[bot]]

# v4.11.81
## (2025-03-17)

* Update actions/setup-node digest to cdca736 [balena-renovate[bot]]

# v4.11.80
## (2025-02-21)

* Update actions/upload-artifact digest to 4cec3d8 [balena-renovate[bot]]

# v4.11.79
## (2025-02-07)

* Update actions/setup-node action to v4 [balena-renovate[bot]]

# v4.11.78
## (2025-02-07)

* Update actions/upload-artifact digest to 65c4c4a [balena-renovate[bot]]

# v4.11.77
## (2025-02-07)

* Update Pin actions/setup-node action to 1a4442c [balena-renovate[bot]]

# v4.11.76
## (2025-02-07)

* Download pre-built UI in Dockerfile.template [Rahul Thakoor]
* Update npm dependencies [Rahul Thakoor]
* Archive build output and upload to github releases [Rahul Thakoor]
* remove build folder [myarmolinsky]
* minimum node and move @types to devdep [myarmolinsky]
* gitignore build, bump balena/lint and lint-staged [myarmolinsky]
* [UI] update react-scripts to v5.x [Rahul Thakoor]
* Build and Publish wifi-connect-ui [Rahul Thakoor]

# v4.11.75
## (2024-12-09)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.74
## (2024-12-02)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.73
## (2024-12-02)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.72
## (2024-11-25)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.71
## (2024-11-18)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.70
## (2024-11-11)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.69
## (2024-11-04)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.68
## (2024-10-29)

* Do not publish the repo to crates.io [Felipe Lalanne]

# v4.11.67
## (2024-10-28)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.66
## (2024-10-21)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.65
## (2024-10-14)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.64
## (2024-10-07)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.63
## (2024-09-23)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.62
## (2024-09-16)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.61
## (2024-09-09)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.60
## (2024-09-09)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.59
## (2024-09-02)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.58
## (2024-08-26)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.57
## (2024-08-19)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.56
## (2024-08-12)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.55
## (2024-08-05)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.54
## (2024-07-29)

* Update Lock file maintenance [balena-renovate[bot]]

# v4.11.53
## (2024-07-22)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.52
## (2024-07-22)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.51
## (2024-07-15)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.50
## (2024-07-08)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.49
## (2024-07-01)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.48
## (2024-06-24)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.47
## (2024-06-17)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.46
## (2024-06-10)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.45
## (2024-06-10)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.44
## (2024-06-03)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.43
## (2024-05-27)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.42
## (2024-05-20)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.41
## (2024-05-13)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.40
## (2024-05-06)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.39
## (2024-04-29)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.38
## (2024-04-24)

* Use latest version and fix release file name in Dockerfile.template [Rahul Thakoor]

# v4.11.37
## (2024-04-22)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.36
## (2024-04-16)

* Enable building and publishing of binaries via flowzone [Rahul Thakoor]

# v4.11.35
## (2024-04-15)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.34
## (2024-04-15)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.33
## (2024-04-08)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.32
## (2024-04-01)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.31
## (2024-03-25)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.30
## (2024-03-18)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.29
## (2024-03-11)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.28
## (2024-03-04)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.27
## (2024-02-26)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.26
## (2024-02-26)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.25
## (2024-02-19)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.24
## (2024-02-12)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.23
## (2024-02-05)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.22
## (2024-01-29)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.21
## (2024-01-22)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.20
## (2024-01-15)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.19
## (2024-01-08)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.18
## (2024-01-01)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.17
## (2024-01-01)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.16
## (2024-01-01)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.15
## (2023-12-25)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.14
## (2023-12-18)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.13
## (2023-12-11)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.12
## (2023-12-11)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.11
## (2023-12-04)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.10
## (2023-11-27)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.9
## (2023-11-20)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.8
## (2023-11-13)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.7
## (2023-11-06)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.6
## (2023-11-06)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.5
## (2023-10-30)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.4
## (2023-10-23)

* Update Lock file maintenance [Self-hosted Renovate Bot]

# v4.11.3
## (2023-05-29)

* Extend renovate config from balena-io/renovate-config [Kyle Harding]

# v4.11.2
## (2023-02-23)

* Pin Raspbian installer to v4.4.6 [Zahari Petkov]

# v4.11.1
## (2023-02-20)

* Remove unused package-lock.json [Zahari Petkov]

# v4.11.0
## (2023-02-20)

* Use Flowzone as a CI and upgrade network-manager crate [Zahari Petkov]

## v4.10.0 - 2022-10-25

* Update Rust crate nix to 0.25.0 [Renovate Bot]

## v4.9.0 - 2022-07-18

* Update Rust crate iron-cors to 0.8.0 [Renovate Bot]

## v4.8.0 - 2022-07-18

* Update Rust crate error-chain to 0.12.4 [Renovate Bot]

## v4.7.0 - 2022-07-18

* Update Rust crate env_logger to 0.9.0 [Renovate Bot]

## v4.6.0 - 2022-07-18

* Update Rust crate clap to 2.34.0 [Renovate Bot]

## v4.5.0 - 2022-07-18

* Update Rust crate nix to 0.24.2 [SECURITY] [Renovate Bot]

## v4.4.6 - 2021-06-30

* Remove CODEOWNERS file [Zahari Petkov]

## v4.4.5 - 2021-04-06

* Point Raspbian installer regex to new repo org `balena-os` [Zahari Petkov]

## v4.4.4 - 2020-10-29

* Terminate dnsmasq gracefully and wait for its exit [Zahari Petkov]

## v4.4.3 - 2020-10-27

* Revert "Run cargo fmt" [Zahari Petkov]

## v4.4.2 - 2020-10-27

* Do not show hidden/empty SSID networks [Zahari Petkov]

## v4.4.1 - 2020-10-07

* Target correctly the arch dockerfile template var [Carlo Maria Curinga]

## v4.4.0 - 2020-08-21

* Allow toggling "show password" on password input [Stevche Radevski]

## v4.3.2 - 2020-08-13

* Allow connections to open networks by providing a default arg [Matthew McGinn]

## v4.3.1 - 2020-05-14

* Remove duplicate SSIDs from network list [Zahari Petkov]

## v4.3.0 - 2020-04-21

* Replace UI with React and Rendition [Stevche Radevski]

## v4.2.13 - 2019-12-27

* Readme: Add balenaOS multicontainer app example. [Tomás Migone]

## v4.2.12 - 2019-10-31

* Ignore unmanaged devices [Zahari Petkov]

## v4.2.11 - 2019-10-23

* Support Buster and future Raspbian versions in the installer [Zahari Petkov]

## v4.2.10 - 2019-09-19

* Delete only the right AP profile on start [Zahari Petkov]

## v4.2.9 - 2019-07-21

* Add link to supported boards/dongles [Robert Vojta]

## v4.2.8 - 2019-07-21

* Optional wait in the start.sh script [Robert Vojta]

## v4.2.7 - 2019-07-20

* Fix incorrect attribute name [Robert Vojta]

## v4.2.6 - 2019-06-26

* Add machine-readable changelog [Gergely Imreh]

## v4.2.5 - 2019-04-02

* Do not manually define GitHub user and repo in the CI [Zahari Petkov]
* Test GitHub token permissions in the CI [Zahari Petkov]

## v4.2.4 - 2019-04-01

* Change the base image to balenalib * install software packages using install_packages [Horia Delicoti]

## v4.2.3 - 2019-03-29

* Add CODEOWNERS [Gergely Imreh]
* Fix python example url [Daniel Andrade]

## v4.2.2 - 2018-11-05

* Change company name [Zahari Petkov]

## v4.2.1 - 2018-07-05

* Cli: Replace env! with clap crate! macros #229 [Robert Vojta]

## v4.2.0 - 2018-06-28

* Auth: WPA-Enterprise support - EAP-PEAP #226 [majorz]

## v4.1.2 - 2018-06-11

* Do not fail on systems without systemd #221 [majorz]

## v4.1.1 - 2018-04-20

* Web server CORS middleware #209 [majorz]

## v4.1.0 - 2018-04-09

* Configurable listening port #204 [majorz]

## v4.0.9 - 2018-04-09

* Install WiFi Connect on Raspbian before activating NetworkManager #205 [majorz]

## v4.0.8 - 2018-03-20

* Require root privileges #193 [majorz]

## v4.0.7 - 2018-03-14

* Fix Raspbian install script auto-canceling #192 [majorz]

## v4.0.6 - 2018-02-20

* Trap exit signals and exit gracefully #183 [majorz]

## v4.0.5 - 2018-02-20

* Remove `clippy` as an optional dependency #182 [majorz]

## v4.0.4 - 2018-02-15

* Exit codes and error-chain error handling #174 [majorz]

## v4.0.3 - 2018-02-08

* Revert passphrase to a proper password field #171 [majorz]

## v4.0.2 - 2018-02-08

* Shorter Raspbian install script URL #170 [majorz]

## v4.0.1 - 2018-02-08

* Load README logo from `master` #169 [majorz]

## v4.0.0 - 2018-01-23

* Support for multiple connection profiles #157 [majorz]

## v3.0.7 - 2018-01-11

* Use Rust NetworkManager bindings v0.8.6 to fix NM v1.10+ incompatibility #156 [majorz]

## v3.0.6 - 2018-01-10

* Rust cross-compilation toolchains update #155 [majorz]

## v3.0.5 - 2018-01-10

* Tweak CSS to line up correctly on more screen sizes #153 [Tim Perry]

## v3.0.4 - 2017-11-07

* Raspbian Stretch install script #117 [majorz]

## v3.0.3 - 2017-11-06

* Improve consistency of new command line arguments #144 [majorz]

## v3.0.2 - 2017-11-03

* Use install UI directory when running from install path #142 [majorz]

## v3.0.1 - 2017-11-02

* Resin-wifi-connect is now WiFi Connect #138 [majorz]

## v3.0.0 - 2017-10-24

* Rust language reimplementation #114 [majorz]

## v2.1.0 - 2017-10-06

* README note for the coming-soon v3 #119 [majorz]

## v2.0.9 - 2017-09-14

* Deprecate version 2 #113 [majorz]

## v2.0.8 - 2017-06-14

* Configurable sleep in the start script [majorz]

## v2.0.7 - 2017-05-08

* Connect to open access points [Joe Roberts]

## v2.0.6 - 2017-04-25

* Fix NM_CONNECTIVITY constants [Joseph Roberts]

## v2.0.5 - 2017-03-08

* Wait for service to start before attempting to connect [Joseph Roberts]

## v2.0.4 - 2017-02-10

* Freeze dbus module version v0.2.19 [Joseph Roberts]

## v2.0.3 - 2017-02-19

* Support intel-edison [Joseph Roberts]

## v2.0.2 - 2016-12-21

* Update readme [Joseph Roberts]

## v2.0.1 - 2016-12-13

* Remove duplicate entries from access point list [Joseph Roberts]
* Enable connection to access points with apostrophes in the SSID [Joseph Roberts]

## v2.0.0 - 2016-12-02

* Support Network Manager [Joseph Roberts]

## v1.0.0 - 2016-12-02

* Bumped version [Joseph Roberts]
